// **************************************************************
//   This class is part of the Sizmek In-Sight Ad Feature
//   ALL RIGHTS RESERVED TO © 2017 Sizmek, Inc.
// **************************************************************
// **************************************************************

(function() {
    // Define Method
    window.InSight = function(_c) {

		"use strict";
        // Save Reference to Script Name
        var scriptName = "In_Sight";
        // Script Version
        var scriptVersion = "3.0.0";
        // Last Modified
        var lastModified = "2017-11-02";
        // Last Uploaded
        var lastUploaded = "2017-11-02";
        // Template Version
        var templateVersion = "2.0.2";
        // Block Id
        var blockId = 6199;
		// Establish Reference to Config Object
		var threshold = _c;
        // Establish Boolean for tracking
        var isDebug = false;
        // Establish Boolean for tracking
        var trackOnce = true;

        // Create Event Handlers for class
        var addEventListener = function(_e, _m, _b) {
            window.addEventListener(_e, _m, _b);
        };
        // Remove Event Handlers for class
        var removeEventListener = function(_e, _m, _b) {
            window.removeEventListener(_e, _m, _b);
        };

        // Call Init Method once AdKit is loaded
        adkit.onReady(function() {
            init();
        });

		// Set up Script
        var init = function() {
			// Track Ad Feature
            trackAdFeatures('impression', 'AF_' + scriptName + '_' + blockId);

			// Try to Add listener - EB not available on local preview
			try {
				// Add Listener
				EB.addEventListener(EBG.EventName.VISIBILITY, function(e) { checkVisibility(); });
			} catch (err) {
				// Call checkVisibility if listener fails
				checkVisibility();
			}
	    };

	    // Handle Messages from Listener
		var checkVisibility = function() {
			// Establish ad default visibility percentage
			var v = 60;
			// Try to determine percentage from delivery
			try { v = EB.getVisibilityData().percentage; } catch (err) {}
			// Check if ad meets threshold for visibility based on config preference
			v = v >= threshold ? true : false;
			// Log Result
			log('v = ', v);
			// Dispatch Event
			setTimeout(function() { dispatchEvent('ON_VISIBILITY', { visibility: v } ); }, 300);
		};

		// DO NOT REMOVE THE FOLLOWING
        //=================================================
        // Utility Functions
        //-------------------------------------------------

        // Handle Dispatching events
        var dispatchEvent = function(_name, _detail) {
            // Establish var for event
            var e = document.createEvent("Event");
            // Init Event
            e.initEvent(_name, true, false);
            // Pass Success Message
            e.detail = _detail;
            // Dispatch Event
            window.dispatchEvent(e);
        };

        // Debugging
        var log = function() { // this is a closure-compiled version of the original code
            if (isDebug) {
                var b, a, c;
                b = Array.prototype.slice.call(arguments);
                a = new Date();
                a = scriptName + " (" + a.getFullYear() + "-" + a.getMonth() + "-" + a.getDate() + " " + (("0" + a.getHours()).slice(-2)) + ":" + (("0" + a.getMinutes()).slice(-2)) + ":" + (("0" + a.getSeconds()).slice(-2)) + "." + (("00" + a.getMilliseconds()).slice(-3)) + "): ";
                b.unshift(a);
                try {
                    window.console && console.log && (console.log.apply ? console.log.apply(console, b) : console.log(b));
                } catch (d) {}
            }
        };

        // Track Ad Features - accepts interaction name and impression type
        var trackAdFeatures = function(_interaction, _noun) {
            // Establish var to track local mode
            var isServed;
            // Verify ad is not local
            try {
                isServed = EB._isServingMode();
            } catch (err) {}

            if (isServed && trackOnce) {
                try {
                    // Update Boolean
                    trackOnce = false;
                    // Grab Version ID
                    var adId = EB._adConfig.adId;
                    // Establish reference for Version id
                    var versionID;
                    // Grab Version ID for mass versioning
                    try { versionID = EB._adConfig.massVersioning.adVersions.split("_")[0]; } catch(err){ versionID = ""; }
                    // Determine if tag is SAS
                    var isNXT = (adId.toString().length >= 10);
                    // Build Base Url for SAS and MDX
                    var baseURL = (isNXT) ? "https://bs.serving-sys.com/BurstingPipe/adServer.bs?cn=tf&c=19&mc=imp&pli=16478984&PluID=0&ord=%time%&rtu=-1&pcp=$$adID=" + adId + "|vId=" + versionID + "|interactionName=" : "https://bs.serving-sys.com/Serving/adServer.bs?cn=display&c=19&pli=1073952795&adid=1073972634&ord=[timestamp]&rtu=-1&pcp=$$adID=" + adId + "|vID=" + versionID + "|interactionName=";
                    // Build Tracking Pixel
                    var trackingPixel = baseURL + _interaction + "|noun=" + _noun + "$$";
                    // Fire Tracking Pixel by creating a new image.
                    new Image().src = trackingPixel;

                } catch (err) {}
            }
        };

        // Return functions you want publically available
        return {
            addEventListener: addEventListener,
            removeEventListener: removeEventListener
        };

    };
}());
